/*
 * Persistent Systems Private Limited, Pune, India (http://www.persistent.co.in)
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that this
 * copyright notice and the following paragraph appears in all
 * copies of this software.
 *
 * DISCLAIMER OF WARRANTY.
 * -----------------------
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND.
 * IN NO EVENT SHALL THE RIGHTHOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */
#ifndef INTERNAL_CONSTANTS
#define INTERNAL_CONSTANTS

/**
* This file contains the constants defined for
* internal use by the C++ Parser.
*
* Globally used constants should be defined in VOTGlobal.h.
*
*/

/* constant strings */

// element names
const char ELE_VOTABLE[] = "VOTABLE";
const char ELE_TABLE[] = "TABLE";
const char ELE_DESC[] = "DESCRIPTION";
const char ELE_DEFN[] = "DEFINITIONS";
const char ELE_FIELD[] = "FIELD";
const char ELE_LINK[] = "LINK";
const char ELE_DATA[] = "DATA";
const char ELE_TABLEDATA[] = "TABLEDATA";
const char ELE_BINARY[] = "BINARY";
const char ELE_FITS[] = "FITS";
const char ELE_TR[] = "TR";
const char ELE_TD[] = "TD";
const char ELE_VALUES[] = "VALUES";
const char ELE_MIN[] = "MIN";
const char ELE_MAX[] = "MAX";
const char ELE_OPTION[] = "OPTION";
const char ELE_RESOURCE[] = "RESOURCE";
const char ELE_INFO[] = "INFO";
const char ELE_COOSYS[] = "COOSYS";
const char ELE_PARAM[] = "PARAM";

// element names as strings of short
const unsigned short SHORT_ELE_VOTABLE[] = {'V','O','T','A','B','L','E','\0'};
const unsigned short SHORT_ELE_TABLE[] = {'T','A','B','L','E','\0'};
const unsigned short SHORT_ELE_RESOURCE[] = {'R','E','S', 'O', 'U', 'R','C','E','\0'};
const unsigned short SHORT_ELE_TR[] = {'T', 'R', '\0'};
const unsigned short SHORT_ELE_TD[] = {'T', 'D', '\0'};
const unsigned short SHORT_ELE_DATA[] = {'D','A','T','A','\0'};
const unsigned short SHORT_ELE_TABLEDATA[] = {'T','A','B','L','E','D','A','T','A','\0'};
const unsigned short SHORT_ELE_BINARY[] = {'B','I','N','A','R','Y','\0'};
const unsigned short SHORT_ELE_FITS[] = {'F','I','T','S','\0'};
const unsigned short SHORT_ELE_DESC[] = {'D','E','S','C','R','I','P','T','I','O','N','\0'};
const unsigned short SHORT_ELE_VALUES[] = {'V','A','L','U','E','S','\0'};
const unsigned short SHORT_ELE_LINK[] = {'L','I','N','K','\0'};
const unsigned short SHORT_ELE_DEFN[] = {'D','E','F','I','N','I','T','I','O','N','S','\0'};
const unsigned short SHORT_ELE_FIELD[] = {'F','I','E','L','D','\0'};
const unsigned short SHORT_ELE_MIN[] = {'M','I','N','\0'};
const unsigned short SHORT_ELE_MAX[] = {'M','A','X','\0'};
const unsigned short SHORT_ELE_OPTION[] = {'O','P','T','I','O','N','\0'};
const unsigned short SHORT_ELE_INFO[] = {'I','N','F','O','\0'};
const unsigned short SHORT_ELE_COOSYS[] = {'C','O','O','S','Y','S','\0'};
const unsigned short SHORT_ELE_PARAM[] = {'P','A','R','A','M','\0'};

// votable attribute names
const char ATTR_VERSION[] = "version";

// votable attribute names as strings of short
const unsigned short SHORT_ATTR_VERSION[] = {'v','e','r','s','i','o','n','\0'};

// table attribute names
const char ATTR_ID[] = "ID";
const char ATTR_NAME[] = "name";
const char ATTR_REF[] = "ref";

// table attribute names as strings of short
const unsigned short SHORT_ATTR_ID[] = {'I','D','\0'};
const unsigned short SHORT_ATTR_NAME[] = {'n','a','m','e','\0'};
const unsigned short SHORT_ATTR_REF[] = {'r','e','f','\0'};

// field attribute names
const char ATTR_UNIT[] = "unit";
const char ATTR_DATATYPE[] = "datatype";
const char ATTR_PRECISION[] = "precision";
const char ATTR_WIDTH[] = "width";
const char ATTR_UCD[] = "ucd";
const char ATTR_ARRAYSIZE[] = "arraysize";
const char ATTR_TYPE[] = "type";

// field attribute names as strings of short

const unsigned short SHORT_ATTR_UNIT[] = {'u','n','i','t','\0'};
const unsigned short SHORT_ATTR_DATATYPE[] = {'d','a','t','a','t','y','p','e','\0'};
const unsigned short SHORT_ATTR_PRECISION[] = {'p','r','e','c','i','s','i','o','n','\0'};
const unsigned short SHORT_ATTR_WIDTH[] = {'w','i','d','t','h','\0'};
const unsigned short SHORT_ATTR_UCD[] = {'u','c','d','\0'};
const unsigned short SHORT_ATTR_ARRAYSIZE[] = {'a','r','r','a','y','s','i','z','e','\0'};
const unsigned short SHORT_ATTR_TYPE[] = {'t','y','p','e','\0'};

// values attribute names
const char ATTR_NULL[] = "null";
const char ATTR_INVALID[] = "invalid";

// values attribute names as strings of short
const unsigned short SHORT_ATTR_NULL[] = {'n','u','l','l','\0'};
const unsigned short SHORT_ATTR_INVALID[] = {'i','n','v','a','l','i','d','\0'};

// min attribute names
const char ATTR_VALUE[] = "value";
const char ATTR_INCLUSIVE[] = "inclusive";

// min attribute names as strings of short
const unsigned short SHORT_ATTR_VALUE[] = {'v','a','l','u','e','\0'};
const unsigned short SHORT_ATTR_INCLUSIVE[] ={'i','n','c','l','u','s','i','v','e','\0'};

// link attribute names
const char ATTR_CONTENT_ROLE[] = "content-role";
const char ATTR_CONTENT_TYPE[] = "content-type";
const char ATTR_TITLE[] = "title";
const char ATTR_HREF[] = "href";
const char ATTR_GREF[] = "gref";
const char ATTR_ACTION[] = "action";

// link attribute names as strings of short
const unsigned short SHORT_ATTR_CONTENT_ROLE[] ={'c','o','n','t','e','n','t','-','r','o','l','e','\0'};
const unsigned short SHORT_ATTR_CONTENT_TYPE[] = {'c','o','n','t','e','n','t','-','t','y','p','e','\0'};
const unsigned short SHORT_ATTR_TITLE[] = {'t','i','t','l','e','\0'};
const unsigned short SHORT_ATTR_HREF[] = {'h','r','e','f','\0'};
const unsigned short SHORT_ATTR_GREF[] = {'g','r','e','f','\0'};
const unsigned short SHORT_ATTR_ACTION[] = {'a','c','t','i','o','n','\0'};

// coosys attribute name
const char ATTR_EQUINOX[] = "equinox";
const char ATTR_EPOCH[] = "epoch";
const char ATTR_SYSTEM[] = "system";

// coosys attribute name as strings of short
const unsigned short SHORT_ATTR_EQUINOX[] = {'e','q','u','i','n','o','x','\0'};
const unsigned short SHORT_ATTR_EPOCH[] = {'e','p','o','c','h','\0'};
const unsigned short SHORT_ATTR_SYSTEM[] = {'s','y','s','t','e','m','\0'};

const char FIELD_DATATYPE[][16] = {"", "boolean", "bit", "unsignedByte", 
			"short", "int", "long", "char", "unicodeChar", "float", "double",
			"floatComplex", "doubleComplex"};

const int NUM_OF_DATATYPES = 12;

const char FIELD_TYPE[][10] = {"", "hidden", "no_query", "trigger" };

const int NUM_OF_FIELD_TYPES = 4;

const char TABLE_DATA_TYPE[][10] = {"", "tabledata", "binary", "fits"};

const char CONTENT_ROLE[][6] = {"", "query", "hints", "doc" };

const int NUM_OF_CONTENT_ROLES = 4;

const char COOSYS_SYSTEM[][15] = {"", "eq_FK4", "eq_FK5", "ICRS", "ecl_FK5",
		"galactic", "supergalactic", "xy", "barycentric", "geo_app"};
		
const int NUM_OF_COOSYS_SYSTEMS = 10;

const char RESOURCE_META_TYPE[] = "meta";
const char RESOURCE_RESULTS_TYPE[] = "results";

const char VALUES_LEGAL_TYPE[] = "legal";
const char VALUES_ACTUAL_TYPE[] = "actual";

const char YES[] = "yes";
const char NO[] = "no";

const char BOOL_TRUE_TYPE1 = 'T';
const char BOOL_TRUE_TYPE2 = 't';
const char BOOL_TRUE_TYPE3 = '1';

const char BOOL_FALSE_TYPE1 = 'F';
const char BOOL_FALSE_TYPE2 = 'f';
const char BOOL_FALSE_TYPE3 = '0';

#endif
