/*
 * Persistent Systems Private Limited, Pune, India (website - http://www.persistent.co.in)
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that this
 * copyright notice and the following paragraph appears in all
 * copies of this software.
 *
 * DISCLAIMER OF WARRANTY.
 * -----------------------
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND.
 * IN NO EVENT SHALL THE RIGHTHOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef PPARSE_H
#define PPARSE_H
// ---------------------------------------------------------------------------
//  Includes for all the program files to see
// ---------------------------------------------------------------------------
#include <iostream.h>
#include <string.h>
#include <stdlib.h>
#include <sax2/SAX2XMLReader.hpp>
#include "PParseHandlers.h"
#include <framework/StdInInputSource.hpp>

/*
 * Progressive Parser used for reading VOTable in chunks.
 */
class PParse
{
public :
	// -----------------------------------------------------------------------
    //  Public methods    
    // -----------------------------------------------------------------------

	/**
	* Constructor
	*/
	PParse();
	
	/**
	* Destructor
	*/
    ~PParse();
    
	/**
	* Initialize parser for standard input stream.
	*/
	int init (void);

	/**
	* Initialize parser for a local file.
	*/
	int init (const char* filename);

	/**
	* Initialize parser for a URL.
	*/
	int init(const char * URL, bool isURL);

	/**
	* Method to parse next token from input.	
	*/
	bool parseNextToken (void);

	/**
	* Terminate the parsers and release memory.
	*/
	int terminate(void);

	/**
	* Returns the handler for VOTables.
	*/
	PParseHandlers * getPParseHandler(void);

private :
    // -----------------------------------------------------------------------
    //  Private data members    
    // -----------------------------------------------------------------------

	// Types of sources
	static const int FROM_LOCAL_FILE;
	static const int FROM_URL;
	static const int FROM_STD_INPUT;
		
	SAX2XMLReader* parser;

	// Handler for VOTable
    PParseHandlers handler;

	XMLPScanToken token;

	// Pointer to input source.
	// Can be a URL, local file or an input stream.
	InputSource * m_inputSource;

	// Pointer to filename or URL.
	char * m_filename;
	XMLCh * xmlch_filename;

	// Type of input source.
	// One of FROM_LOCAL_FILE, FROM_URL or FROM_STD_INPUT.
	int m_srcType;
	

	// -----------------------------------------------------------------------
    //  Private methods
	// -----------------------------------------------------------------------

	int initXML4C(void);
	int initSrc(void);
};

#endif;

