/*
 * Persistent Systems Private Limited, Pune, India (website - http://www.persistent.co.in)
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that this
 * copyright notice and the following paragraph appears in all
 * copies of this software.
 *
 * DISCLAIMER OF WARRANTY.
 * -----------------------
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND.
 * IN NO EVENT SHALL THE RIGHTHOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef PPARSE_HANDLER_H
#define PPARSE_HANDLER_H


#include <sax2/Attributes.hpp>
#include <sax2/DefaultHandler.hpp>
#include "HandlerContext.h"
#include "ContentBuffer.h"
#include "VOTVOTableHandler.h"
#include "RootHandler.h"
class VOTController;

#include <stack>
using namespace std;

class PParseHandlers : public DefaultHandler
{
public :
    // -----------------------------------------------------------------------
    //  Constructors
    // -----------------------------------------------------------------------
    PParseHandlers();
	PParseHandlers(StructureHandler *handler) ;
    ~PParseHandlers();

    // -----------------------------------------------------------------------
    //  Handlers for the SAX DocumentHandler interface
    // -----------------------------------------------------------------------
    
	void startElement(const XMLCh* const uri
                                   , const XMLCh* const localname
                                   , const XMLCh* const qname
                                   , const Attributes& attrs);
    void characters(const XMLCh* const chars, const unsigned int length);    
	void  endElement(const XMLCh *const uri,const XMLCh *const localname,const XMLCh *const qname) ;

	void movetoNextHandler(bool flag, const XMLCh* const qname, const Attributes& attributes);
	void rollbackHandler();
	void setParsing(char * element, bool value);
	void setBufferContent(bool bufferContent);

    // -----------------------------------------------------------------------
    //  Implementations of the SAX ErrorHandler interface
    // -----------------------------------------------------------------------
    void warning(const SAXParseException& exception);
    void error(const SAXParseException& exception);
    void fatalError(const SAXParseException& exception);

	StructureHandler * getElementHandler();
	VOTVOTableHandler * getVOTableHandler();
	VOTResourceHandler * getResourceHandler();
	VOTTableHandler * getTableHandler();
	VOTRowHandler * getRowHandler();
	void setVOTableHandler();
	void setResourceHandler();
	void setTableHandler();
	void setRowHandler();

	int setController(VOTController * controller);


    private:
    // -----------------------------------------------------------------------
    //  Private data members
    //
    //  fAttrCount
    //  fCharacterCount
    //  fElementCount
    //  fSpaceCount
    //      These are just counters that are run upwards based on the input
    //      from the document handlers.
    //
    //  fSawErrors
    //      This is set by the error handlers, and is queryable later to
    //      see if any errors occured.
    // -----------------------------------------------------------------------
    
    bool fSawErrors;

	// Structure handler context stack.
	stack <HandlerContext> m_contextStack;

	// Current nested element depth. 
	int m_nestingDepth;

	// Depth at which to pop handler context. 
	int m_contextDepth;

	// Active structure handler. 
	StructureHandler *m_handler;

	// Pointer to Root, used for deletion
	RootHandler *m_rootHandler;
	

	VOTVOTableHandler * m_votableHandler;
	VOTResourceHandler * m_resourceHandler;
	VOTTableHandler * m_tableHandler;
	VOTRowHandler * m_rowHandler;

	// Character data collection buffer. 
	ContentBuffer m_contentBuffer;

	VOTController * m_controller;

	
	void printXMLString(const XMLCh *str);
	void init(void);
};

#endif;

