#ifndef ROOT_HANDLER_H
#define ROOT_HANDLER_H

#include "StructureHandler.h"
#include "VOTVOTableHandler.h"
#include <stdlib.h>
#include <stdio.h>


/*
* This is the handler class for the root element of the document
*/


class RootHandler : public StructureHandler
{
public:
	/*
	* Default Constructor
	*/
	RootHandler();

	/*
	* Deconstructor
	*/
	~RootHandler();

	/*
	* This method is called when the starting tag of the element is parsed
	* It stores the attributes, if any, of the element
	*/
	void startElement(const XMLCh* const qname, const Attributes& attrs);

	/*
	* This method is called when the ending tag of the element is parsed.
	* It stores the PCData of the element
	*/
	void endElement(const XMLCh* const qname, const XMLCh* const chars, const unsigned int length);

	/*
	* This method is called when the starting tag of a child element is parsed.
	* It returns a pointer to the child element's handler
	*/
	StructureHandler * startChild(const XMLCh* const qname, const Attributes& attrs);	

	/*
	* This method is calledwhen the ending tag of the child element is parsed.
	* It gets the data of the child element & stores in this element
	*/
	void endStructureChild(const XMLCh* const qname, StructureHandler *handler);

protected:
	/*
	* Dummy function
	*/
	void doNothing();

private:
	// VOTVOTableHandler for handling <DESCRIPTION> element.
	VOTVOTableHandler * m_votableMetaDataHandler;
	
};

#endif