/*
 * Persistent Systems Private Limited, Pune, India (website - http://www.pspl.co.in)
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that this
 * copyright notice and the following paragraph appears in all
 * copies of this software.
 *
 * DISCLAIMER OF WARRANTY.
 * -----------------------
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND.
 * IN NO EVENT SHALL THE RIGHTHOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef VOT_COLUMN_H
#define VOT_COLUMN_H

#include "VOTGlobal.h"
#include <util/XMLString.hpp>
#include <vector>

using namespace std;

/**
 * This class represents the column element &lt;TD&gt; in a &lt;TABLE&gt;.  
 * 
 * Column contains data in the primitive form.
 * It may also contain an array. 
 *
 */

/// This class represents the column element &lt;TD&gt; in a &lt;TABLE&gt;.  

// Date created - 03 May 2002
class VOTColumn {

	public:

		/** 
		 * Default constructor.		 
		 */
		VOTColumn();

		/** 
		 * Default deconstructor.		 
		 */
		~VOTColumn();

		/**
		 * Assignment operator overloaded.
		 */ 
		VOTColumn operator=(const VOTColumn &column);

		/**
		 * Copy constructor.
		 */ 
		VOTColumn(const VOTColumn &column);

		/**
		 * Gets the data in a boolean array. If the data in some array location is
		 * not boolean, this will be indicated by a INVALID_DATATYPE_ERROR in the 
		 * corresponding array location of the 'valid' array.
		 * @param boolArray The boolean array to get the data
		 * @param valid Indicates whether data in the corresponding array location
		 *  in the data array is of the correct datatype. A value of VOT_SUCCESS 
		 * indicates success and INVALID_DATATYPE_ERROR indicates an error.
		 * @param numOfElements Number of elements in the data array
		 * @return VOT_SUCCESS if data array has valid data, else VOT_ERROR.
		 */
		int getLogicalArray(Bool *&boolArray, int *&valid, int &numOfElements) ;

		/**
		 * Gets the data in a bit array.
		 * @param bitArray The bit array to get the data
		 * @param numOfElements Number of elements in the data array
		 * @return VOT_SUCCESS if data array has valid data, else VOT_ERROR
		 */
		int getBitArray(char *&bitArray, int &numOfElements) ;

		/**
		 * Gets the data in a byte array
		 * @param byteArray The byte array to get the data
		 * @param numOfElements Number of elements in the data and valid array
		 * @return VOT_SUCCESS if data array has valid data, else VOT_ERROR.
		 */
		int getByteArray(unsigned char *&byteArray, int &numOfElements) ;

		/**
		 * Gets the data in a short array. If the data in some array location is
		 * not short, this will be indicated by a INVALID_DATATYPE_ERROR in the 
		 * corresponding array location of the 'valid' array.
		 * @param shortArray The short array to get the data
		 * @param valid Indicates whether data in the corresponding array location
		 *  in the data array is of the correct datatype. A value of VOT_SUCCESS 
		 * indicates success and INVALID_DATATYPE_ERROR indicates an error.
		 * @param numOfElements Number of elements in the data and valid array.
		 * @return VOT_SUCCESS if data array has valid data, else VOT_ERROR.
		 */
		int getShortArray(short *&shortArray, int *&valid, int &numOfElements) ;

		/**
		 * Gets the data in an integer array. If the data in some array location is
		 * not int, this will be indicated by a INVALID_DATATYPE_ERROR in the 
		 * corresponding array location of the 'valid' array.
		 * @param intArray The int array to get the data
		 * @param valid Indicates whether data in the corresponding array location
		 *  in the data array is of the correct datatype. A value of VOT_SUCCESS 
		 * indicates success and INVALID_DATATYPE_ERROR indicates an error.
		 * @param numOfElements Number of elements in the data and valid array.
		 * @return VOT_SUCCESS if data array has valid data, else VOT_ERROR.
		 */
		int getIntArray(int *&intArray, int *&valid, int &numOfElements) ;

		/**
		 * Gets the data in a long array. If the data in some array location is
		 * not long, this will be indicated by a INVALID_DATATYPE_ERROR in the 
		 * corresponding array location of the 'valid' array.
		 * @param longArray The long array to get the data
		 * @param valid Indicates whether data in the corresponding array location
		 *  in the data array is of the correct datatype. A value of VOT_SUCCESS 
		 * indicates success and INVALID_DATATYPE_ERROR indicates an error.
		 * @param numOfElements Number of elements in the data and valid array.
		 * @return VOT_SUCCESS if data array has valid data, else VOT_ERROR.
		 */
		int getLongArray(long *&longArray, int *&valid, int &numOfElements) ;

		/**
		 * Gets the data in a char array
		 * @param charArray The char array to get the data
		 * @param numOfElements Number of elements in the data array.
		 * @return VOT_SUCCESS if data array has valid data, else VOT_ERROR
		 */
		int getCharArray(char *&charArray,int &numOfElements) ;

		/**
		 * Gets the unicode data array
		 * @param unicodeArray The unsigned short array to get the data
		 * @param numOfElements Number of elements in the data array.
		 * @return VOT_SUCCESS if data array has valid data, else VOT_ERROR.
		 */
		int getUnicodeArray(unsigned short *&unicodeArray, int &numOfElements) ;
		
		/**
		 * Gets the data in a float array. If the data in some array location is
		 * not float, this will be indicated by a INVALID_DATATYPE_ERROR in the 
		 * corresponding array location of the 'valid' array.
		 * @param floatArray The float array to get the data
		 * @param valid Indicates whether data in the corresponding array location
		 *  in the data array is of the correct datatype. A value of VOT_SUCCESS 
		 * indicates success and INVALID_DATATYPE_ERROR indicates an error.
		 * @param numOfElements Number of elements in the data and valid array.
		 * @return VOT_SUCCESS if data array has valid data, else VOT_ERROR.
		 */
		int getFloatArray(float *&floatArray, int *&valid, int &numOfElements) ;

		/**
		 * Gets the data in a double array. If the data in some array location is
		 * not double, this will be indicated by a INVALID_DATATYPE_ERROR in the 
		 * corresponding array location of the 'valid' array.
		 * @param doubleArray The double array to get the data
		 * @param valid Indicates whether data in the corresponding array location
		 *  in the data array is of the correct datatype. A value of VOT_SUCCESS 
		 * indicates success and INVALID_DATATYPE_ERROR indicates an error.
		 * @param numOfElements Number of elements in the data and valid array.
		 * @return VOT_SUCCESS if data array has valid data, else VOT_ERROR.
		 */
		int getDoubleArray(double *&doubleArray, int *&valid, int &numOfElements) ;

		/**
		 * Gets the complex data as float array. If the data in some array location is
		 * not float, this will be indicated by a INVALID_DATATYPE_ERROR in the 
		 * corresponding array location of the 'valid' array.
		 * @param complexArray The float array to get the data
		 * @param valid Indicates whether data in the corresponding array location
		 *  in the data array is of the correct datatype. A value of VOT_SUCCESS 
		 * indicates success and INVALID_DATATYPE_ERROR indicates an error.
		 * @param numOfElements Number of elements in the data and valid array.
		 * @return VOT_SUCCESS if data array has valid data, else VOT_ERROR.
		 */
		int getFloatComplexArray(float *&complexArray, int *&valid, int &numOfElements) ;

		/**
		 * Gets the complex data as double array. If the data in some array location is
		 * not double, this will be indicated by a INVALID_DATATYPE_ERROR in the 
		 * corresponding array location of the 'valid' array.
		 * @param complexArray The double array to get the data
		 * @param valid Indicates whether data in the corresponding array location
		 *  in the data array is of the correct datatype. A value of VOT_SUCCESS 
		 * indicates success and INVALID_DATATYPE_ERROR indicates an error.
		 * @param numOfElements Number of elements in the data and valid array.
		 * @return VOT_SUCCESS if data array has valid data, else VOT_ERROR
		 */
		int getDoubleComplexArray(double *&complexArray, int *&valid, int &numOfElements) ;

		/**
		 * Gets attribute 'ref' of &lt;TD&gt;.
		 */
		int getRef(char * &ref);

		/*
		 * Reinitializes all the data structures in the class
		 */
		void reset(void);	

		 // Stores the character data
		int setCharData(char * data);

		 // Stores the unicode data
		int setUnicodeData (unsigned short *data, int size);

		 // Stores the value of 'ref' attrubute
		int setRef(char * ref);
	
	private: 
		// The character data of &lt;TD&gt;
		char * m_data;

		// The reference value of &lt;TD&gt;
		char * m_ref;	

		// The unicode data of &lt;TD&gt;
		unsigned short * m_unicodeData;

		// The unicode data size 
		int m_size; 

		// Is the &lt;TD&gt; data unicode
		bool m_isUnicode;

		// Gets the array of strings
		vector <char *> getArrayOfStrings(char *data, int &numberOfElets);

		// Checks is the string is a valid number
		bool isValidNumber(char *num, field_datatype dt);

		// Checks is the string is a valid integer
		bool isValidInteger(char * num);

		// Gets the &lt;TD&gt; data stored in the class
		int getData(char *&c, int &len);

		// Delete all data stored in the class
		void cleanup();

		// Copies all data from the passed object to <i>this</i> object
		void makecopy(const VOTColumn &c);

		// Initialise the data in the class
		void init(void);

		// Trims the trailing white spaces
		void trim(char *&str);
};

#endif
