/*
 * Persistent Systems Private Limited, Pune, India (website - http://www.pspl.co.in)
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that this
 * copyright notice and the following paragraph appears in all
 * copies of this software.
 *
 * DISCLAIMER OF WARRANTY.
 * -----------------------
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND.
 * IN NO EVENT SHALL THE RIGHTHOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef COOSYS_H
#define COOSYS_H

#include "VOTGlobal.h"

/**
* This class represents &lt;COOSYS&gt; element.  
*
* A VOTCoosys element contains ID, equinox, epoch and system.
*/

/// This class represents &lt;COOSYS&gt; element

class VOTCoosys {

	public:
		/**
		* Default constructor
		*/
		VOTCoosys();

		/**
		* Destructor
		*/
		~VOTCoosys();

		/**
		* Assignment operator overloaded.
		*/
		VOTCoosys operator=(const VOTCoosys &coosys);

		/**
		* Copy Constructor
		*/
		VOTCoosys(const VOTCoosys &coosys);
		
		/**
		* Gets the 'equinox' attribute.
		*/
		int getEquinox(char * &equinox);

		/**
		* Gets the 'ID' attribute.
		*/
		int getID(char * &infoID);

		/**
		* Gets the 'epoch' attribute.
		*/
		int getEpoch(char * &epoch);

		/**
		* Gets the PCDATA.
		*/
		int getPCData(char * &pcdata);

		/**
		* Gets the 'system' attribute.
		*/
		int getSystem(coosys_system &system);

		int setEquinox(char * infoValue);
		int setID(char * infoID);
		int setEpoch(char * epoch);
		int setPCData(char * pcdata);
		int setSystem(coosys_system system);
		void reset(void);
	
	private: 
		char * m_ID;
		char * m_equinox;
		char * m_epoch;
		coosys_system m_system;
		char * m_pcdata;
		
		void cleanup();
		void makecopy(const VOTCoosys &r);
		void init(void);
};

#endif
