/*
 * Persistent Systems Private Limited, Pune, India (http://www.persistent.co.in)
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that this
 * copyright notice and the following paragraph appears in all
 * copies of this software.
 *
 * DISCLAIMER OF WARRANTY.
 * -----------------------
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND.
 * IN NO EVENT SHALL THE RIGHTHOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef COOSYS_HANDLER_H
#define COOSYS_HANDLER_H

#include "StructureHandler.h"
#include "VOTCoosys.h"
#include "InternalConstants.h"

/*
* This is the handler class for the coosys element, &lt;COOSYS&gt;
*
* Methods of this class are called by the parser to store the attributes
* & data of the &lt;COOSYS&gt; element
*
*/
class VOTCoosysHandler : public StructureHandler
{
public:
	/*
	* Default Constructor
	*/
	VOTCoosysHandler();

	/*
	* Deconstructor
	*/
	~VOTCoosysHandler();

	/*
	* This method is called when the starting tag of the element is parsed
	* It stores the attributes, if any, of the element
	*/
	void startElement(const XMLCh* const qname, const Attributes& attrs);

	/*
	* This method is called when the ending tag of the element is parsed.
	* It stores the PCData of the element
	*/
	void endElement(const XMLCh* const qname, const XMLCh* const chars, const unsigned int length);

	/*
	* Get system of the coosys.
	*/
	coosys_system getCoosysSystem(const char * type);

	/*
	* Get the data corresponding to this element
	*/
	VOTCoosys getData();

	/*
	* Dummy function
	*/
	void doNothing();

private:
	
	VOTCoosys m_coosys;
		
};

#endif