/*
 * Persistent Systems Private Limited, Pune, India (http://www.persistent.co.in)
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that this
 * copyright notice and the following paragraph appears in all
 * copies of this software.
 *
 * DISCLAIMER OF WARRANTY.
 * -----------------------
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND.
 * IN NO EVENT SHALL THE RIGHTHOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef DEFINITION_HANDLER_H
#define DEFINITION_HANDLER_H

#include "StructureHandler.h"
#include "VOTDefinition.h"
#include "InternalConstants.h"
#include "VOTCoosysHandler.h"
#include "VOTParamHandler.h"
#include "VOTCoosys.h"
#include "VOTParam.h"
#include <stdio.h>
/*
* This is the handler class for the definition element, &lt;DEFINITION&gt;
*
* Methods of this class are called by the parser to store the attributes
* & data of the &lt;DEFINITION&gt; element
*
*/

class VOTDefinitionHandler : public StructureHandler
{
public:


	/*
	* Default Constructor
	*/
	VOTDefinitionHandler();

	/*
	* Deconstructor
	*/
	~VOTDefinitionHandler();

	/*
	* This method is called when the starting tag of the element is parsed
	* It stores the attributes, if any, of the element
	*/
	void startElement(const XMLCh* const qname, const Attributes& attrs);

	/*
	* This method is called when the starting tag of a child element is parsed.
	* It returns a pointer to the child element's handler
	*/
	StructureHandler * startChild(const XMLCh* const qname, const Attributes& attrs);	

	/*
	* This method is calledwhen the ending tag of the child element is parsed.
	* It gets the data of the child element & stores in this element
	*/
	void endStructureChild(const XMLCh* const qname, StructureHandler *handler);

	/*
	* Get the data corresponding to this element
	*/
	VOTDefinition getData();

	/*
	* Dummy function
	*/
	void doNothing();

private:
	
	VOTDefinition m_definition;
	VOTCoosysHandler * m_coosysHandler;
	VOTParamHandler * m_paramHandler;

	
};

#endif