/*
 * Persistent Systems Private Limited, Pune, India (website - http://www.pspl.co.in)
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that this
 * copyright notice and the following paragraph appears in all
 * copies of this software.
 *
 * DISCLAIMER OF WARRANTY.
 * -----------------------
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND.
 * IN NO EVENT SHALL THE RIGHTHOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef VOT_FIELD_H
#define VOT_FIELD_H

#include "VOTFieldParam.h"

/**
 * This class represents &lt;FIELD&gt; element in a &lt;TABLE&gt;.
 *
 * A field contains description, a max of 2 values and a
 * list of links.
 *
 */

/// This class represents &lt;FIELD&gt; element in a &lt;TABLE&gt;.

//Date created - 03 May 2002

class VOTField : public VOTFieldParam {

	public:

		/**
		* Default constructor
		*/
		VOTField();

		/**		
		 * Default destructor
		*/
		~VOTField();

		/**		
		* Assignment operator overloaded.
		*/
		VOTField operator=(const VOTField &field);

		/**
		* Copy constructor
		*/
		VOTField(const VOTField &field);

		/**
		* Gets the 'type' of the field. 'field_type' is defined in 'VOTGlobal.h'.
		*/
		int getType (field_type &type);

		// Sets the 'type' of field
		int setType (field_type type);		

		/**
		* Reinitializes the data in the class
		*/
		void reset(void);

	private:

		// The type of field
		field_type m_type;

		// Dummy function - does nothing
		void doNothing(void);		

		// Initialises the data in the class
		void init(void);

		// Delete all data stored in the class
		void cleanup(void);
		
		// Copies all data from the passed object to <i>this</i> object
		void makecopy(const VOTField &f);
};

#endif
