/*
 * Persistent Systems Private Limited, Pune, India (http://www.persistent.co.in)
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that this
 * copyright notice and the following paragraph appears in all
 * copies of this software.
 *
 * DISCLAIMER OF WARRANTY.
 * -----------------------
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND.
 * IN NO EVENT SHALL THE RIGHTHOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef VOT_FIELD_HANDLER_H
#define VOT_FIELD_HANDLER_H

#include "StructureHandler.h"
#include "InternalConstants.h"
#include "VOUtils.h"
#include "VOTField.h"
#include "VOTFieldParamHandler.h"

using namespace std;

/*
* This is the handler class for the field element, &lt;FIELD&gt;
*
* Methods of this class are called by the parser to store the attributes
* & data of the &lt;FIELD&gt; element
*
*/

class VOTFieldHandler:public VOTFieldParamHandler
{

public:

	/*
	* Default Constructor
	*/
	VOTFieldHandler();

	/*
	* Deconstructor
	*/
	~VOTFieldHandler();

	/*
	* This method is called when the starting tag of the element is parsed
	* It stores the attributes, if any, of the element
	*/
	void startElement(const XMLCh* const qname, const Attributes& attrs);

	/*
	* This method is called when the ending tag of the element is parsed.
	* It stores the PCData of the element
	*/
	void endElement(const XMLCh* const qname, const XMLCh* const chars, const unsigned int length);

	/*
	* This method is called when the starting tag of a child element is parsed.
	* It returns a pointer to the child element's handler
	*/
	StructureHandler * startChild(const XMLCh* const qname, const Attributes& attrs);	

	/*
	* This method is calledwhen the ending tag of the child element is parsed.
	* It gets the data of the child element & stores in this element
	*/
	void endStructureChild(const XMLCh* const qname, StructureHandler *handler);

	/*
	* Convert the string to field_type
	*/
	field_type toFieldType(const char *type);

	/*
	* Get the data corresponding to this element
	*/
	VOTField *  getData();

	/*
	* Dummy function
	*/
	void doNothing();

private:
	VOTField * copyOfFieldParam;

};

#endif