/*
 * Persistent Systems Private Limited, Pune, India (website - http://www.pspl.co.in)
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that this
 * copyright notice and the following paragraph appears in all
 * copies of this software.
 *
 * DISCLAIMER OF WARRANTY.
 * -----------------------
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND.
 * IN NO EVENT SHALL THE RIGHTHOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef VOT_FIELDPARAM_H
#define VOT_FIELDPARAM_H

#include "VOTGlobal.h"
#include "VOTValues.h"
#include "VOTLink.h"

#include <util/XMLString.hpp>
#include <vector>

using namespace std;

XERCES_CPP_NAMESPACE_USE

/**
 *
 * This class is an abstract class, base class of &lt;FIELD&gt; and &lt;PARAM&gt;.
 *
 * This class represents the Field/Param in the MetaData.
 * A Field/Param contains description, a max of 2 values and a
 * list of links.
 *
 * The <FIELD> and <PARAM> class only differ in some attributes.
 * <FIELD> contains 'type' and <PARAM> contains 'value'.
 *
 */

/// This class is an abstract class, base class of &lt;FIELD&gt; and &lt;PARAM&gt;

//Date created - 27 May 2002

class VOTFieldParam {

	public:

		VOTFieldParam();


		~VOTFieldParam();
		/**
		* Gets the description.
		*/
		int getDescription (char * &desc);

		/**
		* Gets the number of <VALUES> elements.
		*/
		int getNumOfValues (int &numOfValues);

		/**
		* Gets 'Values', given the index.
		* Index starts at 0.
		*/
		int getValues (VOTValues &values, int index);

		/**
		* Gets number of links.
		*/
		int getNumOfLinks (int  &nLinks);

		/**
		* Gets the 'Link' at the given index.
		* Index starts at 0.
		*/
		int getLink (VOTLink &link, int linkNum);

		/**
		* Gets the ID.
		*/
		int getID (char * &ID);

		/**
		* Gets the unit.
		*/
		int getUnit (char * &unit);

		/**
		* Gets the datatype. 'field_datatype' is an enumeration defined
		* in 'VOTGlobal.h'.
		*/
		int getDatatype (field_datatype &datatype);

		/**
		* Gets the precision.
		*/
		int getPrecision (char * &precision);

		/**
		* Gets the width.
		*/
		int getWidth (int &width);

		/**
		* Gets the ref.
		*/
		int getRef (char * &ref);

		/**
		* Gets the name.
		*/
		int getName (char * &name);

		/**
		* Gets the UCD.
		*/
		int getUCD (char * &ucd);

		/**
		* Gets the arraysize.
		*/
		int getArraySize (char * &arraySize);

		/**
		* Checks whether data is of variable type.
		*/
		int isVariableType (bool &b);

		// Sets the ID
		int setID(char * ID);

		// Sets the Unit
		int setUnit(char * unit);

		// Sets the Datatype
		int setDatatype(field_datatype datatype);
		
		// Sets the Precision
		int setPrecision(char * precision);
		
		// Sets the Width
		int setWidth(int width);
		
		// Sets the Ref
		int setRef(char * ref);
		
		// Sets the Name
		int setName(char * name);
		
		// Sets the UCD
		int setUCD(char * ucd);
		
		// Sets the Array size
		int setArraySize(char * arraySize);

		// To be implemented in the subclass FIELD.
		virtual int setType(field_type type);

		// To be implemented in the subclass PARAM.
		virtual int setValue(char *str);

		// Sets the Description
		int setDescription(char * desc);
		
		// Sets the Links
		int setLinks(vector<VOTLink> links);
		
		// Adds a Link
		int addLink(VOTLink oneLink);
		
		// Sets the Values
		int setValues(vector<VOTValues> values);
		
		// Adds a Value
		int addValue(VOTValues oneValue);
		
		/*
		* Reinitializes the class
		*/
		virtual void reset(void);

	protected:
		// Vector for storing VOTValues
		vector<VOTValues> m_values;

		//Vector for storing VOTLink
		vector<VOTLink> m_linkList;

		// Description of the element 
		char * m_description;

		// ID of the element
		char * m_ID;

		// Unit of the element
		char * m_unit;

		// Datatype of the element
		field_datatype m_datatype;
		
		// Precision of the element
		char * m_precision;
		
		// Width of the element
		unsigned int m_width;
		
		// Ref of the element
		char * m_ref;

		// Name of the element
		char * m_name;
		
		// UCD of the element
		char * m_UCD;
		
		// Array size of the element
		char * m_arraySize;

		// To be implemented in the subclasses.
		virtual void cleanup(void);
		
		// To be implemented in the subclasses.
		virtual void makecopy(const VOTFieldParam &f);

		// To be implemented in the subclasses.
		virtual void init(void);

		// Dummy function - does nothing
		virtual void doNothing(void)=0;

};

#endif
