/*
 * Persistent Systems Private Limited, Pune, India (http://www.persistent.co.in)
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that this
 * copyright notice and the following paragraph appears in all
 * copies of this software.
 *
 * DISCLAIMER OF WARRANTY.
 * -----------------------
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND.
 * IN NO EVENT SHALL THE RIGHTHOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef INFO_HANDLER_H
#define INFO_HANDLER_H

#include "StructureHandler.h"
#include "VOTInfo.h"
#include "InternalConstants.h"

/*
* This is the handler class for the field element, &lt;FIELD&gt;
*
* Methods of this class are called by the parser to store the attributes
* & data of the &lt;FIELD&gt; element
*
*/

class VOTInfoHandler : public StructureHandler
{
public:

	/*
	* Default Constructor
	*/
	VOTInfoHandler();

	/*
	* Deconstructor
	*/
	~VOTInfoHandler();

	/*
	* This method is called when the starting tag of the element is parsed
	* It stores the attributes, if any, of the element
	*/
	void startElement(const XMLCh* const qname, const Attributes& attrs);

	/*
	* This method is called when the ending tag of the element is parsed.
	* It stores the PCData of the element
	*/
	void endElement(const XMLCh* const qname, const XMLCh* const chars, const unsigned int length);

	/*
	* Get the data corresponding to this element
	*/
	VOTInfo getData();

protected:
	/*
	* Dummy function
	*/
	void doNothing(void)
	{
	}

private:
	
	VOTInfo m_info;
		
};

#endif