/*
 * Persistent Systems Private Limited, Pune, India (website - http://www.pspl.co.in)
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that this
 * copyright notice and the following paragraph appears in all
 * copies of this software.
 *
 * DISCLAIMER OF WARRANTY.
 * -----------------------
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND.
 * IN NO EVENT SHALL THE RIGHTHOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef VOT_LINK_H
#define VOT_LINK_H

#include "VOTGlobal.h"

/**
* This class represents &lt;LINK&gt; element. 
*
* A &lt;LINK&gt; consists of ID, content-role, content-type, title, value,
* href, gref and action.
*/

/// This class represents &lt;LINK&gt; element

class VOTLink {

	public:
		/**
		* Default constructor.
		*/
		VOTLink();

		//Link(char *ID, char * pcdata, char * contentType, content_role contentRole,
		//	  char * title, char * linkvalue, char *value, char * href, char * gref, 
		//	  char *action);

		/**
		* Destructor.
		*/
		~VOTLink();

		/**
		* Assignment operator overloaded.
		*/
		VOTLink operator=(const VOTLink &link);

		/**
		* Copy constructor.
		*/
		VOTLink(const VOTLink &link);

		/**
		* Gets the 'ID'.
		*/
		int getID(char * &ID);

		/**
		* Gets the 'PCData'.
		*/
		int getPCData(char * &pcdata);

		/**
		* Gets the 'content-type'.
		*/
		int getContentType(char * &contentType);

		/**
		* Gets the 'content-role'.'content-role' is defined in 'VOTGlobal.h'.
		*/
		int getContentRole(content_role & contentRole );

		/**
		* Gets the 'title'.
		*/
		int getTitle(char * &title);

		/**
		* Gets the 'value'.
		*/
		int getValue(char * &value);

		/**
		* Gets the 'href'.
		*/
		int getHRef(char * &href);

		/**
		* Gets the 'gref'.
		*/
		int getGRef(char * &gref);

		/**
		* Gets the 'action'.
		*/
		int getAction(char * &action);	
		
		/*
		 * Reinitializes all the data structures in the class
		 */
		void reset(void);

		int setID(char * ID);
		int setPCData(char * pcdata);
		int setContentType(char * contentType);
		int setContentRole(content_role contentRole );
		int setTitle(char * title);
		int setValue(char * value);
		int setHRef(char * href);
		int setGRef(char * gref);
		int setAction(char * action);	
	
	private: 
		char * m_ID;
		char * m_pcdata;
		char * m_contentType;
		content_role m_contentRole;
		char * m_title;
		char * m_linkvalue;
		char * m_href;
		char * m_gref;
		char * m_action;

		void makeCopy(const VOTLink &l);
		void cleanup(void);
		void init(void);
};

#endif
