/*
 * Persistent Systems Private Limited, Pune, India (website - http://www.pspl.co.in)
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that this
 * copyright notice and the following paragraph appears in all
 * copies of this software.
 *
 * DISCLAIMER OF WARRANTY.
 * -----------------------
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND.
 * IN NO EVENT SHALL THE RIGHTHOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef VOT_OPTION_H
#define VOT_OPTION_H

#include "VOTGlobal.h"
#include <vector>
using namespace std;

/**
* This class represents &lt;OPTION&gt; element.
*
* An Option element consists of a name and value.
*/

/// This class represents &lt;OPTION&gt; element.

//Date created - 05 May 2002

class VOTOption {

	public:
		/**
		* Default constructor.
		*/
		VOTOption();
		
		/**
		* Destructor
		*/
		~VOTOption();

		/**
		* Assignment operator overloaded.
		*/
		VOTOption operator=(const VOTOption &option);

		/**
		* Copy constructor.
		*/
		VOTOption(const VOTOption &option);

		/**
		* Gets the 'name'.
		*/
		int getName(char * &name);

		/**
		* Gets the 'value'.
		*/
		int getValue(char * &value);

		/**
		* Gets the 'Option', given the index.
		* Index starts at 0.
		*/
		int getOption(VOTOption &option, int index);

		/**
		* Gets the number of options.
		*/
		int getNumOfOptions(int &numOfOptions);

		/*
		* Reinitializes all the data structures in the class
		*/		
		void reset(void);
		
		// Sets the name
		int setName(char * name);
		
		// Sets the Value
		int setValue(char * value);

		// Sets the VOTOption
		int setOptions(vector <VOTOption> optionList);
		
		// Adds a VOTOption
		int addOption(VOTOption opt);

	private:
		// Name of the &lt;OPTION&gt;
		char * m_name;

		// Value of the &lt;OPTION&gt;
		char * m_value;

		//  Vector for storing VOTOption
		vector <VOTOption> m_optionList;

		// Initialises the data in the class
		void init(void);

		// Delete all data stored in the class
		void cleanup(void);
		
		// Copies all data from the passed object to <i>this</i> object
		void makecopy(const VOTOption &o);
};

#endif
