/*
 * Persistent Systems Private Limited, Pune, India (website - http://www.pspl.co.in)
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that this
 * copyright notice and the following paragraph appears in all
 * copies of this software.
 *
 * DISCLAIMER OF WARRANTY.
 * -----------------------
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND.
 * IN NO EVENT SHALL THE RIGHTHOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef VOT_RANGE_H
#define VOT_RANGE_H

#include "VOUtils.h"

/**
* This class represents &lt;MIN&gt; and &lt;MAX&gt; element inside &lt;VALUES&gt; element.
*
* Range consists of value and inclusive flag.
*/

/// This class represents &lt;MIN&gt; and &lt;MAX&gt; element inside &lt;VALUES&gt; element.

//Date created - 05 May 2002

class VOTRange {

	public:
		/**
		* Default Constructor
		*/
		VOTRange();

		/**
		* Destructor
		*/
		~VOTRange();

		/**
		* Assignment operator overloaded.
		*/
		VOTRange operator=(const VOTRange &range);

		/**
		* Copy Constructor
		*/
		VOTRange(const VOTRange &range);

		/**
		* Gets the 'value'
		*/
		int getValue(char * &rangeValue);

		/**
		* Gets 'false' if inclusive is 'no', true otherwise.
		*/
		int isInclusive(bool &inclusive);

		/**
		* Gets the PCDATA.
		*/
		int getPCData(char * &pcdata);

		/*
		* Reinitializes all the data structures in the class
		*/
		void reset();

		// Sets the value
		int setValue(char * rangeValue);

		// Sets the PCData
		int setPCData(char * pcdata);

		// Sets the boolean inclusive flag
		int setInclusiveFlag(bool inclusive);		

	private:

		// Value of the range
		char * m_rangeValue;

		// Boolean inclusive flag
		bool m_inclusive;

		// PCdata 
		char * m_pcdata;

		// Initialises the data in the class
		void init(void);

		// Delete all data stored in the class
		void cleanup(void);
		
		// Copies all data from the passed object to <i>this</i> object
		void makecopy(const VOTRange &r);
};

#endif
