/*
 * Persistent Systems Private Limited, Pune, India (http://www.persistent.co.in)
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that this
 * copyright notice and the following paragraph appears in all
 * copies of this software.
 *
 * DISCLAIMER OF WARRANTY.
 * -----------------------
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND.
 * IN NO EVENT SHALL THE RIGHTHOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef RESOURCE_HANDLER_H
#define RESOURCE_HANDLER_H

#include "StructureHandler.h"
#include "VOTResource.h"
#include "InternalConstants.h"
#include "VOTDescriptionHandler.h"
#include "VOTDescription.h"
#include "VOTInfoHandler.h"
#include "VOTInfo.h"
#include "VOTCoosysHandler.h"
#include "VOTCoosys.h"
#include "VOTLinkHandler.h"
#include "VOTLink.h"
#include "VOTParamHandler.h"
#include "VOTTableHandler.h"

/*
* This is the handler class for the resource element, &lt;RESOURCE&gt;
*
* Methods of this class are called by the parser to store the attributes
* & data of the &lt;RESOURCE&gt; element
*
*/

class VOTResourceHandler : public StructureHandler
{
public:

	/*
	* Default Constructor
	*/
	VOTResourceHandler();

	/*
	* Deconstructor
	*/
	~VOTResourceHandler();

	/*
	* This method is called when the starting tag of the element is parsed
	* No attributes are stored, only nested depth is updated
	*/
	void startElement();

	/*
	* This method is called when the starting tag of the element is parsed
	* It stores the attributes, if any, of the element
	*/
	void startElement(const XMLCh* const qname, const Attributes& attrs);

	/*
	* This method is called when the ending tag of the element is parsed.
	* It stores the PCData of the element
	*/
	void endElement(const XMLCh* const qname, const XMLCh* const chars, const unsigned int length);

	/*
	* This method is called when the starting tag of a child element is parsed.
	* It returns a pointer to the child element's handler
	*/
	StructureHandler * startChild(const XMLCh* const qname, const Attributes& attrs);	

	/*
	* This method is calledwhen the ending tag of the child element is parsed.
	* It gets the data of the child element & stores in this element
	*/
	void endStructureChild(const XMLCh* const qname, StructureHandler *handler);

	/*
	* Convert the string to resource_type 
	*/
	resource_type getResourceType(const char * str_type);

	/*
	* Set the nesting depth of this resource
	*/
	void setNestedDepth(int nestedDepth);

	/*
	* Get the data corresponding to this element
	*/
	VOTResource getData();

protected:
	/*
	* dummy function
	*/
	void doNothing(void);

private:
	
	VOTResource m_resource;
	VOTDescriptionHandler * m_descriptionHandler;
	VOTLinkHandler * m_linkHandler;
	VOTInfoHandler * m_infoHandler;
	VOTCoosysHandler * m_coosysHandler;
	VOTParamHandler * m_paramHandler;
	VOTResourceHandler * m_resourceHandler;
	VOTTableHandler * m_tableHandler;

	int m_nestedDepth;
	bool isResourceCreated;
		
};

#endif