/*
 * Persistent Systems Private Limited, Pune, India (website - http://www.pspl.co.in)
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that this
 * copyright notice and the following paragraph appears in all
 * copies of this software.
 *
 * DISCLAIMER OF WARRANTY.
 * -----------------------
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND.
 * IN NO EVENT SHALL THE RIGHTHOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef VOT_ROW_H
#define VOT_ROW_H

#include "VOTGlobal.h"
#include "VOTColumn.h"
#include <vector>
using namespace std;

/**
* This class represents the &lt;TR&gt; in a &lt;TABLE&gt;.  
* 
* Row contains a list of 'Column' objects. 
*
*/

/// This class represents the &lt;TR&gt; in a &lt;TABLE&gt;

// Date created - 03 May 2002

class VOTRow {

	public:	
		/**
		* Default Constructor.
		*/
		VOTRow();


		/**
		* Destructor
		*/
		~VOTRow();

		/**
		* Assignment operator overloaded.
		*/
		VOTRow operator=(const VOTRow &row);

		/**
		* Copy Constructor
		*/
		VOTRow(const VOTRow &row);

		/**
		* Gets the 'Column', given the column index. 
		* Index starts from 0.
		*/
		int getColumn(VOTColumn &column, int index);

		/**
		* Gets total number of Columns.
		*/
		int getNumOfColumns(int  &nCols);

		/*
		* Reinitializes all the data structures in the class
		*/
		void reset(void);

		// Sets the VOTColumn in the row
		int setColumns(vector<VOTColumn> colList);

		// Adds a VOTColumn in a row
		int addColumn(VOTColumn oneColumn);
		
	
	private: 
		// Vector to store the VOTColumn
		vector<VOTColumn> m_columnList;

		// Delete all data stored in the class
		void cleanup(void);
		
		// Copies all data from the passed object to <i>this</i> object
		void makecopy(const VOTRow &row);
};

#endif
