/*
 * Persistent Systems Private Limited, Pune, India (website - http://www.persistent.co.in)
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that this
 * copyright notice and the following paragraph appears in all
 * copies of this software.
 *
 * DISCLAIMER OF WARRANTY.
 * -----------------------
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND.
 * IN NO EVENT SHALL THE RIGHTHOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef VOT_TABLE_H
#define VOT_TABLE_H

#include "VOTGlobal.h"
#include "VOTField.h"
#include "VOTLink.h"
#include <vector>
using namespace std;

/**
*
* This class represents the &lt;TABLE&gt; element in the &lt;RESOURCE&gt;
*
* A VOTTable consists of meta-data i.e. FIELDS and LINKS.
* <b>Note:</b> It does not contain the actual row data. 
* 
*/

/// This class represents the &lt;TABLE&gt; element in the &lt;RESOURCE&gt;

class VOTTable
{

	public:

		static vector<bool> m_isUnicode;
		
		/**
		* Default constructor
		*/
		VOTTable();

		/**
		* Destructor
		*/
		~VOTTable();

		/**
		* Assignment operator
		*/
		VOTTable operator=(const VOTTable &table);

		/**
		* Copy constructor
		*/
		VOTTable(const VOTTable &table);

		/**
		* Gets 'name'.
		*/
		int getName(char * &name);

		/**
		* Gets 'ID'. 
		*/
		int getID(char * &ID);

		/** 
		* Gets 'Ref'.
		*/
		int getRef(char * &ref);

		/**
		* Gets the type of data in the TABLE element.
		* Type can be either FITS, BINARY, TABLEDATA or none.
		*/
		int getDataType (table_data_type &type);

		/**
		* Gets total number of Columns i.e. <FIELD> elements
		* in this table.
		*/
		int getNumOfColumns(int  &ncols);

		/**
		* Gets total number of Links.
		*/
		int getNumOfLinks(int  &nLinks);

		/**
		* Gets 'Field', given the index.
		* Index starts at 0.
		*/
		int getField(VOTField &field, int fieldNum);

		/**
		* Gets 'Link', given the index.
		* Index starts at 0.
		*/
		int getLink(VOTLink &link, int linkNum);

		/**
		* Gets the description of the Table.
		*/
		int getDescription(char *&desc);

		/*
		* Reinitializes all the data structures in the class
		*/		
		void reset();

		// Set Table name
		int setName(char * name);

		// Set Table ID.
		int setID(char * ID);

		// Set Table Reference
		int setRef(char * ref);

		// Sets Description
		int setDescription(char *desc);

		// Sets the VOTField vector
		int setFields(vector<VOTField> f);

		// Sets the VOTLink vector
		int setLinks(vector<VOTLink> l);

		// Adds a VOTField to the vector
		int addField(VOTField f);

		// Adds a VOTLink to the vector
		int addLink(VOTLink l);

		// Sets the datatype
		int setDataType (table_data_type type);

	private:

		// ID of the TABLE
		char * m_ID;

		// Name of the TABLE
		char * m_name;

		// ref of the TABLE
		char * m_ref;

		// Description of the TANLE
		char * m_description;

		// Vector for storing VOTField
		vector<VOTField> m_fieldList;

		// Vector for storing VOTLink
		vector<VOTLink> m_linkList;

		// Datatype of the table
		table_data_type m_dataType;

		// Initialises the data in the class
		void init(void);

		// Delete all data stored in the class
		void cleanup(void);
		
		// Copies all data from the passed object to <i>this</i> object
		void makecopy(const VOTTable &t);
};

#endif