/*
 * Persistent Systems Private Limited, Pune, India (website - http://www.persistent.co.in)
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that this
 * copyright notice and the following paragraph appears in all
 * copies of this software.
 *
 * DISCLAIMER OF WARRANTY.
 * -----------------------
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND.
 * IN NO EVENT SHALL THE RIGHTHOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef VOT_VOTABLE_H
#define VOT_VOTABLE_H

#include <iostream.h>

#include <vector>
using namespace std;

#include "VOTDefinition.h"
#include "VOTInfo.h"
#include "VOTResource.h"

/**
* Represents the &lt;VOTABLE&gt; element in the VOTable.
* It contains attributes and meta data in the VOTable element.
*/

/// Represents the &lt;VOTABLE&gt; element in the VOTable.

class VOTVOTable
{
public:

	/**
	* Default constructor.
	*/
	VOTVOTable();

	/**
	* Destructor.
	*/
	~VOTVOTable();

	/**
	* Assignment operator overloaded.
	*/
	VOTVOTable operator=(const VOTVOTable &votable);

	/**
	* Copy constructor
	*/
	VOTVOTable(const VOTVOTable &votable);

	/**
	* Get VOTable ID.
	*/
	int getID(char * &id);

	/**
	* Get VOTable version.
	*/
	int getVersion(char * & version);

	/**
	* Get VOTable description.
	*/
	int getDescription(char * & desc);

	/**
	* Get VOTable definition.
	*/
	int getDefinition(VOTDefinition *&defn);

	/**
	* Get VOTable Info, given an index.
	*/
	int getInfo(VOTInfo &info, int infoIndex);

	/**
	* Get number of Infos.
	*/
	int getNumOfInfos(int &numOfInfos);

	int setID(char *id);
	int setVersion(char *version);
	int setDescription(char *description);
	int setDefinition(VOTDefinition defn);
	int setInfo(vector<VOTInfo> info);
	int addInfo(VOTInfo info);

private:
	// member variables
	char * m_ID;
	char * m_version;
	char * m_description;
	VOTDefinition * m_definition;
	vector <VOTInfo> m_infoList;

	// private methods
	void makecopy(const VOTVOTable &v);
	void cleanup(void);
	void init(void);

};
#endif