#ifndef VOTABLE_META_DATA_HANDLER_H
#define VOTABLE_META_DATA_HANDLER_H

#include "StructureHandler.h"
#include "VOTDescriptionHandler.h"
#include "VOTDefinitionHandler.h"
#include "VOTInfoHandler.h"
#include "VOTResourceHandler.h"
#include "VOTVOTable.h"
#include "InternalConstants.h"
#include "VOTDescription.h"
#include "VOTDefinition.h"
#include "VOTResource.h"
#include "VOTInfo.h"
#include <stdlib.h>
#include <stdio.h>

/*
* This is the handler class for the votable element, &lt;VOTABLE&gt;
*
* Methods of this class are called by the parser to store the attributes
* & data of the &lt;VOTABLE&gt; element
*
*/

class VOTVOTableHandler : public StructureHandler
{
public:

	/*
	* Default Constructor
	*/
	VOTVOTableHandler();

	/*
	* Deconstructor
	*/
	~VOTVOTableHandler();

	/*
	* This method is called when the starting tag of the element is parsed
	* It stores the attributes, if any, of the element
	*/
	void startElement(const XMLCh* const qname, const Attributes& attrs);

	/*
	* This method is called when the ending tag of the element is parsed.
	* It stores the PCData of the element
	*/
	void endElement(const XMLCh* const qname, const XMLCh* const chars, const unsigned int length);

	/*
	* This method is called when the starting tag of a child element is parsed.
	* It returns a pointer to the child element's handler
	*/
	StructureHandler * startChild(const XMLCh* const qname, const Attributes& attrs);	

	/*
	* This method is calledwhen the ending tag of the child element is parsed.
	* It gets the data of the child element & stores in this element
	*/
	void endStructureChild(const XMLCh* const qname, StructureHandler *handler);

	/*
	* Get the data corresponding to this element
	*/
	VOTVOTable getData();

protected:
	/*
	* dummy function
	*/
	void doNothing(void);


private:
	// description handler for handling <DESCRIPTION> element.
	VOTDescriptionHandler * m_descriptionHandler;

	// definition handler for handling <DEFINITION> element.
	VOTDefinitionHandler * m_definitionHandler;

	// info handler for handling <INFO> element.
	VOTInfoHandler * m_infoHandler;

	// resource handler for handling <RESOURCE> element.
	VOTResourceHandler * m_resourceHandler;

	// contains VOTable meta data
	VOTVOTable m_votableMetaData;



};

#endif