/*
 * Persistent Systems Private Limited, Pune, India (website - http://www.pspl.co.in)
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that this
 * copyright notice and the following paragraph appears in all
 * copies of this software.
 *
 * DISCLAIMER OF WARRANTY.
 * -----------------------
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND.
 * IN NO EVENT SHALL THE RIGHTHOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */
#ifndef VOT_VALUES_H
#define VOT_VALUES_H

#include "VOTGlobal.h"
#include "VOTRange.h"
#include "VOTOption.h"

#include <vector>
using namespace std;

/**
* This class represents &lt;VALUES&gt; element in &lt;FIELD&gt;.
*
* A Values element consists of a Minimum, Maximum and
* a collection of Options.
*
*/

/// This class represents &lt;VALUES&gt; element in &lt;FIELD&gt;.

// Date created - 05 May 2002

class VOTValues {

	public:
		/**
		* Default Constructor
		*/
		VOTValues();

		/**
		* Destructor
		*/
		~VOTValues();

		/**
		* Assignment operator overloaded.
		*/
		VOTValues operator=(const VOTValues &values);

		/**
		* Copy Constructor
		*/
		VOTValues(const VOTValues &values);

		/**
		* Gets the 'ID'.
		*/
		int getID(char * &ID);

		/**
		* Gets the 'type'. 'values_type' is defined in 'gloabal'h'.
		*/
		int getType(values_type & type);

		/**
		* Gets the 'null'.
		*/
		int getNull(char * &null);

		/**
		* Gets the 'invalid', true if 'invalid' is 'yes'.
		*/
		int isValid(bool &invalid );

		/**
		* Gets the <MIN>.
		*/
		int getMinimum(VOTRange * &min);

		/**
		* Gets the <MAX>.
		*/
		int getMaximum(VOTRange * &max);

		/**
		* Gets the 'Option', given the index.
		* Index starts at 0.
		*/
		int getOption(VOTOption & option, int index);

		/**
		* Gets the number of Options.
		*/
		int getNumOfOptions(int &numOfOptions);

		/*
		* Reinitializes all the data structures in the class
		*/
		void reset(void);

		// Sets the ID
		int setID(char * ID);

		// Sets type
		int setType(values_type type);
		
		// Sets whether null
		int setNull(char * null);
		
		// Sets whether invalid
		int setInvalidFlag(bool invalid);
		
		// Sets the minimum value
		int setMinimum(VOTRange  min);
		
		// Sets the maximum value
		int setMaximum(VOTRange  max);
		
		// Sets the VOTOption
		int setOptions(vector<VOTOption> option);
		
		// Adds a VOTOption to the list
		int addOption(VOTOption option);		

	private:

		// ID of the VALUE
		char * m_ID;

		// Type of value
		values_type m_type;

		// Null value
		char * m_nullval;
		
		// Is invalid
		bool m_invalid;

		// Minimum value
		VOTRange * m_minimum;
		
		// Maximum value
		VOTRange * m_maximum;

		// Vector for storing VOTOption
		vector<VOTOption> m_optionList;

		// Initialises the data in the class
		void init(void);

		// Delete all data stored in the class
		void cleanup(void);
		
		// Copies all data from the passed object to <i>this</i> object
		void makecopy(const VOTValues &v);

};

#endif
