/*
 * Persistent Systems Private Limited, Pune, India (http://www.persistent.co.in)
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that this
 * copyright notice and the following paragraph appears in all
 * copies of this software.
 *
 * DISCLAIMER OF WARRANTY.
 * -----------------------
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND.
 * IN NO EVENT SHALL THE RIGHTHOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

/*
 * This is a sample program to test the C++ Streaming Parser APIs
 * Created om 09 May 2003
 */

//Include files
#include <iostream.h>
#include <exception>
#include "VOTParser.h"
#include "PrintElementContents.h"

using namespace std;

// extern functions used.
extern void printResourceContents(VOTResource &r);
extern void printTableContents(VOTTable &table);
extern void printVOTableMetaDataContents(VOTVOTable &v);
extern void printRowContents(VOTRow &r, VOTTable &v);

void parseCompleteDocument();

//The VOTParser object to be used for parsing
VOTParser votableParser;


int main(int argC, char* argV[])
{
	if (argC != 2)
	{
		cerr << "Usage : PrintAllData votable" << endl;
		return 1;
	}
	try
	{
		//Initialize the parser for the given VOTable file
		if (VOT_SUCCESS == votableParser.init(argV[1]))
		{
			parseCompleteDocument();
		}

	} catch (const std::exception&  ex)
	{
		cout << "Exception " << ex.what() << endl;
	}

	cout << "\nCompleted parsing." << endl;

	//Close the parser - must be called before exiting
	votableParser.close();
	return 0;
}

/* 
* Print all the data in the VOTable 
*/
void parseCompleteDocument()
{
	//VOTVOTable object to get the VOTable meta-data
	VOTVOTable votableMetaData;

	//If valid VOTable meta-data is available ...
	if (VOT_SUCCESS == votableParser.getVOTableMetaData(votableMetaData))
	{
		//print the VOTable meta-data
		printVOTableMetaDataContents(votableMetaData);
	}

	int type;
	//While there is a next Resource or Table available in the VOTable ...
	while (votableParser.getNextResourceOrTable(type) == VOT_SUCCESS)
	{
		//If the element found is a Resource ...
		if(type == VOTParser::VOTABLE_RESOURCE)
		{
			VOTResource r;
			//Get the current Resource & print its contents
			votableParser.getResource(r);
			printResourceContents(r);

		}
		//If the element found is a Table ...
		else if(type == VOTParser::VOTABLE_TABLE)
		{
			VOTTable t;
			//Get the current Table & print its contents
			votableParser.getTable(t);
			printTableContents(t);
			//While this Table has more rows ...
			while(votableParser.nextRow() == VOT_SUCCESS)
			{
				VOTRow r;
				//Get one row & print its contents
				votableParser.getRow(r);
				printRowContents(r,t);
			}
			
		}
	}
}
