/*
 * Persistent Systems Private Limited, Pune, India (http://www.persistent.co.in)
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that this
 * copyright notice and the following paragraph appears in all
 * copies of this software.
 *
 * DISCLAIMER OF WARRANTY.
 * -----------------------
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND.
 * IN NO EVENT SHALL THE RIGHTHOLDER BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

/*
 * This is a sample program to test the C++ Streaming Parser APIs
 * Created om 09 May 2003
 */

//Include files
#include <iostream.h>
#include <exception>
#include "VOTParser.h"
#include "PrintElementContents.h"

using namespace std;

// extern functions used.
extern void printResourceContents(VOTResource &r);
extern void printTableContents(VOTTable &table);
extern void printVOTableMetaDataContents(VOTVOTable &v);
extern void printRowContents(VOTRow &r, VOTTable &v);

void getNthTable(int n);

//The VOTParser object to be used for parsing
VOTParser votableParser;


int main(int argC, char* argV[])
{
	//Get the third table
	int n = 3;

	if (argC != 2)
	{
		cerr << "Usage : PrintNthTable votable" << endl;
		return 1;
	}
	try
	{
		//Initialize the parser for the given VOTable file
		if (VOT_SUCCESS == votableParser.init(argV[1]))
		{
			getNthTable(n);
		}

	} catch (const std::exception&  ex)
	{
		cout << "Exception " << ex.what() << endl;
	}

	cout << "Completed parsing." << endl;

	//Close the parser - must be called before exiting
	votableParser.close();
	return 0;
}

/* 
* Print the Nth table in the VOTable 
*/
void getNthTable(int n)
{
	int cnt=0;

	//Go through the VOTable document till 'n' tables are parsed.
	//This continues irrespective of the Resource boundaries. The parser
	//will stop at the nth table in the VOTable 
	while(cnt<n && votableParser.nextTable() == VOT_SUCCESS)
	{
		cnt++;
	}

	//VOTTable object to get the table meta-data
	VOTTable t;

	//Get the table & print its contents
	votableParser.getTable(t);
	printTableContents(t);

}
