/*
 * This is a sample program to test the C++ Streaming Parser APIs
 * Created om 09 May 2003
 */

//Include files
#include <iostream.h>
#include <exception>
#include "VOTParser.h"
#include "PrintElementContents.h"

using namespace std;

// extern functions used.
extern void printResourceContents(VOTResource &r);
extern void printTableContents(VOTTable &table);
extern void printVOTableMetaDataContents(VOTVOTable &v);
extern void printRowContents(VOTRow &r, VOTTable &v);

void getRequiredTable(int n,int m);

//The VOTParser object to be used for parsing
VOTParser votableParser;


int main(int argC, char* argV[])
{
	//Get the nth table after the mth resource
	int n = 2;
	int m = 2;
	if (argC != 2)
	{
		cerr << "Usage : PrintAllData votable" << endl;
		return 1;
	}
	try
	{
		//Initialize the parser for the given VOTable file
		if (VOT_SUCCESS == votableParser.init(argV[1]))
		{
			getRequiredTable(n,m);
		}

	} catch (const std::exception&  ex)
	{
		cout << "Exception " << ex.what() << endl;
	}

	cout << "\nCompleted parsing." << endl;

	//Close the parser - must be called before exiting
	votableParser.close();
	return 0;
}

/* 
* Print all the data in the VOTable 
*/
void getRequiredTable(int n, int m)
{
	int cnt=0;

	//VOTResource object to get the resource meta-data
	VOTResource r;

	//Continue parsing till the mth resource element is parsed
	while(cnt<m && votableParser.nextResource() == VOT_SUCCESS)
	{
		cnt++;
	}	

	//Get the mth resource element & print its meta-data
	//GetResource() returns resource meta-data (ie all elements' data
	//till start-of-table or start-of-nested-resource or end-of-resource)
	if (VOT_SUCCESS == votableParser.getResource(r))
	{
		printResourceContents(r);
	}

	cnt=0;
	//Continue parsing till the nth table element is parsed
	//This will cross the resource boundary if the current resource element
	//does not have n tables
	while(cnt<n && votableParser.nextTable() == VOT_SUCCESS)
	{
		cnt++;
	}

	//Get the nth table element & print its meta-data
	VOTTable t;
	if (VOT_SUCCESS == votableParser.getTable(t))
	{
		printTableContents(t);
	}

	
	//Get & print data of all the rows in this nth table. This will retrieve
	//the rows of only this table. It will not cross the table boundary
	VOTRow row;
	while (VOT_SUCCESS == votableParser.nextRow() && VOT_SUCCESS == votableParser.getRow(row))
	{
		printRowContents(row, t);
	}
}
