/*
* Thie file has all the functions to print the attribute-value pairs
* of all the elements of the VOTable.
*/

#include <iostream.h>
#include "VOTParser.h"
#include "VOTResource.h"

#include <exception>
using namespace std;

// Function declarations
void printResourceContents(VOTResource &r);
void printCoosysContents(VOTCoosys &c);
void printInfoContents(VOTInfo &i);
void printLinkContents(VOTLink &l, int index);
void printFieldContents(VOTField &field, int index);
void printParamContents(VOTParam &param, int index);
void printTableContents(VOTTable &table);
void printOptionContents(VOTOption &o);
void printRangeContents(VOTRange &r);
void printValuesContents(VOTValues &v);
void printVOTableMetaDataContents(VOTVOTable &v);
void printRowContents(VOTRow &r, VOTTable &table);
//void printColumnContents(VOTColumn &c);
void printDefinitionContents(VOTDefinition &defn);
void printFieldParamContents(VOTFieldParam &f, int index, bool isField);
void printData(VOTColumn &c, field_datatype dt);
void printBits(char c);


/*
* Print VOTable meta data.
*/
void printVOTableMetaDataContents(VOTVOTable &v)
{
	cout << "\n ************************** PRINTING VOTABLE CONTENTS *******************" << endl;
	char * str = NULL;

	//Print the VOTable ID, if available
	if (VOT_SUCCESS == v.getID(str) && NULL != str)
	{
		cout << "VOTable ID is " << str << " , ";
		delete[] str;
	}

	//Print the VOTable version, if available
	if (VOT_SUCCESS == v.getVersion(str) && NULL != str)
	{
		cout << "VOTable version is " << str << " , ";
		delete[] str;
	}

	//Print the VOTable description, if available
	if (VOT_SUCCESS == v.getDescription(str) && NULL != str)
	{
		cout << "VOTable description is " << str << " , ";
		delete[] str;
	}

	//Print details of the VOTable definition, if available
	VOTDefinition * defn = NULL;
	if (VOT_SUCCESS == v.getDefinition(defn) && NULL != defn)
	{
		printDefinitionContents(*defn);
		delete defn;
	}

	//Print details of the VOTable info, if available
	int numOfInfos = 0;
	if (VOT_SUCCESS == v.getNumOfInfos(numOfInfos) && numOfInfos > 0)
	{
		for (int i = 0; i < numOfInfos; i++)
		{
			VOTInfo info;
			if (VOT_SUCCESS == v.getInfo(info, i))
			{
				cout << "VOTable INFO " << (i+1) << " is " << " , ";
				printInfoContents(info);
			}
		}
	}
	cout << "\n=========================================================================" << endl;
}

/*
* Print Resource data.
*/
void printResourceContents(VOTResource &r)
{
	cout << "\n ************************** PRINTING RESOURCE CONTENTS *******************" << endl;
	char * str = NULL;

	//Print the Resource ID, if available
	if (VOT_SUCCESS == r.getID(str) && NULL != str)
	{
		cout << "ID is " << str << " , ";
		delete[] str;
	}

	//Print the Resource Depth, if available
	int depth;
	if (VOT_SUCCESS == r.getNestedDepth(depth))
	{
		cout << "Nested Depth is " << depth << " , ";
	}

	//Print the Resource Name, if available
	if (VOT_SUCCESS == r.getName(str) && NULL != str)
	{
		cout << "Name is " << str << " , ";
		delete[] str;
	}

	//Print the Resource Type, if available
	resource_type type;
	if (VOT_SUCCESS == r.getType(type))
	{
		cout << "Type is " << type << " , ";
	}

	//Print the Resource Description, if available
	if (VOT_SUCCESS == r.getDescription(str) && NULL != str)
	{
		cout << "Description is " << str << " , ";
		delete[] str;
	}

	int numOfElts = 0;

	//Print details of the Resource params, if available
	r.getNumOfParams(numOfElts);
	cout << "\nNumber of PARAMS is " << numOfElts << " , ";
	if(numOfElts > 0)
	{
		VOTParam param;

		for(int i=0;i<numOfElts;i++)
		{
			r.getParam(param, i);
			printParamContents(param, i+1);
		}
	}

	//Print details of the Resource coosys, if available
	r.getNumOfCoosys(numOfElts);
	cout << "\nNumber of COOSYS is " << numOfElts << " , ";
	if (numOfElts > 0)
	{
		VOTCoosys coosys;

		for (int i = 0; i < numOfElts; i++)
		{
			r.getCoosys(coosys, i);
			printCoosysContents(coosys);
		}
	}

	//Print details of the Resource info, if available
	r.getNumOfInfos(numOfElts);
	cout << "\nNumber of INFO is " << numOfElts << " , ";
	if (numOfElts > 0)
	{
		VOTInfo info;

		for (int i = 0; i < numOfElts; i++)
		{
			r.getInfo(info, i);
			printInfoContents(info);
		}
	}

	//Print details of the Resource links, if available
	r.getNumOfLinks(numOfElts);
	cout << "\nNumber of LINKS in RESOURCE is " << numOfElts << " , ";
	if (numOfElts > 0)
	{
		VOTLink link;

		for (int i = 0; i < numOfElts; i++)
		{
			r.getLink(link, i);
			printLinkContents(link, i+1);
		}
	}
	cout << "\n=========================================================================" << endl;
	return;
}

/*
* Print Coosys data.
*/
void printCoosysContents(VOTCoosys &c)
{
	char * str = NULL;
	cout << "\n";

	//Print the Coosys ID, if available
	if (VOT_SUCCESS == c.getID(str) && str != NULL)
	{
		cout << "Coosys ID is " << str << " , ";
		delete[] str;
	}

	//Print the Coosys equinox, if available
	if (VOT_SUCCESS == c.getEquinox(str) && str != NULL)
	{
		cout << "Coosys equinox is " << str << " , ";
		delete[] str;
	}

	//Print the Coosys epoch, if available
	if (VOT_SUCCESS == c.getEpoch(str) && str != NULL)
	{
		cout << "Coosys epoch is " << str << " , ";
		delete[] str;
	}

	//Print the Coosys PCData, if available
	if (VOT_SUCCESS == c.getPCData(str) && str != NULL)
	{
		cout << "Coosys PCData is " << str << " , ";
		delete[] str;
	}

	//Print the Coosys system, if available
	coosys_system sys;
	if (VOT_SUCCESS == c.getSystem(sys))
	{
		cout << "Coosys system is " << sys << " , ";
	}
}

/*
* Print info data.
*/
void printInfoContents(VOTInfo &i)
{
	char * str = NULL;
	cout << "\n";

	//Print Info ID, if available
	if (VOT_SUCCESS == i.getID(str) && str != NULL)
	{
		cout << "Info ID is " << str << " , ";
		delete[] str;
	}

	//Print Info name, if available
	if (VOT_SUCCESS == i.getName(str) && str != NULL)
	{
		cout << "Info name is " << str << " , ";
		delete[] str;
	}

	//Print Info value, if available
	if (VOT_SUCCESS == i.getValue(str) && str != NULL)
	{
		cout << "Info value is " << str << " , ";
		delete[] str;
	}

	//Print Info PCData, if available
	if (VOT_SUCCESS == i.getPCData(str) && str != NULL)
	{
		cout << "Info PCData is " << str << " , ";
		delete[] str;
	}
}

/*
* Print Link data.
*/
void printLinkContents(VOTLink &l, int index)
{
	char * str = NULL;
	cout << "\n";
	cout << "LINK " << index << " ";

	//Print Link ID, if available
	if (VOT_SUCCESS == l.getID(str) && str != NULL)
	{
		cout << "ID is " << str << " , ";
		delete[] str;
	}

	//Print Link content type, if available
	if (VOT_SUCCESS == l.getContentType(str) && str != NULL)
	{
		cout << "content type is " << str << " , ";
		delete[] str;
	}

	//Print Link value, if available
	if (VOT_SUCCESS == l.getValue(str) && str != NULL)
	{
		cout << "value is " << str << " , ";
		delete[] str;
	}

	//Print Link title, if available
	if (VOT_SUCCESS == l.getTitle(str) && str != NULL)
	{
		cout << "title is " << str << " , ";
		delete[] str;
	}

	//Print Link href, if available
	if (VOT_SUCCESS == l.getHRef(str) && str != NULL)
	{
		cout << "href is " << str << " , ";
		delete[] str;
	}

	//Print Link gref, if available
	if (VOT_SUCCESS == l.getGRef(str) && str != NULL)
	{
		cout << "gref is " << str << " , ";
		delete[] str;
	}

	//Print Link action, if available
	if (VOT_SUCCESS == l.getAction(str) && str != NULL)
	{
		cout << "action is " << str << " , ";
		delete[] str;
	}

	//Print Link PCData, if available
	if (VOT_SUCCESS == l.getPCData(str) && str != NULL)
	{
		cout << "PCData is " << str << " , ";
		delete[] str;
	}

	//Print Link content role, if available
	content_role r;
	if (VOT_SUCCESS == l.getContentRole(r))
	{
		cout << "content role is " << r << " , ";
	}
}

/*
* Print Table data.
*/
void printTableContents(VOTTable &t)
{
	cout << "\n ************************** PRINTING TABLE CONTENTS *******************" << endl;
	char * str = NULL;

	//Print Table ID, if available
	if (VOT_SUCCESS == t.getID(str) && NULL != str)
	{
		cout << "ID is " << str << " , ";
		delete[] str;
	}

	//Print Table Name, if available
	if (VOT_SUCCESS == t.getName(str) && NULL != str)
	{
		cout << "Name is " << str << " , ";
		delete[] str;
	}

	//Print Table Ref, if available
	if (VOT_SUCCESS == t.getRef(str) && NULL != str)
	{
		cout << "Ref is " << str << " , ";
		delete[] str;
	}

	//Print Table Description, if available
	if (VOT_SUCCESS == t.getDescription(str) && NULL != str)
	{
		cout << "Description is " << str << " , ";
		delete[] str;
	}

	//Print Table Data format, if available
	table_data_type type;
	if (VOT_SUCCESS == t.getDataType(type))
	{
		cout << "Data format is " << type << " , ";
	}


	int numOfElts = 0;

	//Print details of Table LINKS, if available
	t.getNumOfLinks(numOfElts);
	cout << "\nNumber of LINKS : " << numOfElts << " , ";
	if (numOfElts > 0)
	{
		VOTLink link;

		for (int i = 0; i < numOfElts; i++)
		{
			t.getLink(link, i);
			printLinkContents(link, i+1);
		}
	}

	//Print details of Table FIELDS, if available
	t.getNumOfColumns(numOfElts);
	cout << "\nNumber of FIELDS : " << numOfElts << " , ";
	if (numOfElts > 0)
	{
		VOTField field;

		for (int i = 0; i < numOfElts; i++)
		{
			t.getField(field, i);
			printFieldContents(field, i+1);
		}
	}
	cout << "\n=========================================================================" << endl;

}

/*
* Print Field & Param data (they have the same set of attributes)
*/
void printFieldParamContents(VOTFieldParam &f, int index, bool isField)
{
	char * str = NULL;
	cout << "\n";

	if (isField)
	{
		cout << "FIELD " << index << ": " ;
	}
	else
	{
		cout << "PARAM " << index << ": " ;
	}

	//Print Field/Param ID, if available
	if (VOT_SUCCESS == f.getID(str) && NULL != str)
	{
		cout << "ID is " << str << " , ";
		delete[] str;
	}

	//Print Field/Param Name, if available
	if (VOT_SUCCESS == f.getName(str) && NULL != str)
	{
		cout << "Name is " << str << " , ";
		delete[] str;
	}

	//Print Field/Param Unit, if available
	if (VOT_SUCCESS == f.getUnit(str) && NULL != str)
	{
		cout << "Unit is " << str << " , ";
		delete[] str;
	}

	//Print Field/Param Datatype, if available
	field_datatype type;
	if (VOT_SUCCESS == f.getDatatype(type))
	{
		cout << "Datatype is " << type << " , ";
	}

	//Print Field/Param Precision, if available
	if (VOT_SUCCESS == f.getPrecision(str) && NULL != str)
	{
		cout << "Precision is " << str << " , ";
		delete[] str;
	}

	//Print Field/Param Width, if available
	int w;
	if (VOT_SUCCESS == f.getWidth(w))
	{
		cout << "Width is " << w << " , ";
	}

	//Print Field/Param Ref, if available
	if (VOT_SUCCESS == f.getRef(str) && NULL != str)
	{
		cout << "Ref is " << str << " , ";
		delete[] str;
	}

	//Print Field/Param UCD, if available
	if (VOT_SUCCESS == f.getUCD(str) && NULL != str)
	{
		cout << "UCD is " << str << " , ";
		delete[] str;
	}

	//Print Field/Param Array Size, if available
	if (VOT_SUCCESS == f.getArraySize(str) && NULL != str)
	{
		cout << "Array Size is " << str << " , ";
		delete[] str;
	}

	//Print Field/Param Variable, if available
	bool b;
	if (VOT_SUCCESS == f.isVariableType(b))
	{
		cout << "Variable :  " << b << " , ";
	}

	cout << endl;
	int numOfElts = 0;

	//Print details of Field/Param links, if available
	f.getNumOfLinks(numOfElts);
	if (isField)
	{
		cout << "\nNumber of LINKS in FIELD " << index << " is " << numOfElts << endl;
	} 
	else
	{
		cout << "\nNumber of LINKS in PARAM " << index << " is " << numOfElts << endl;
	}
	if (numOfElts > 0)
	{
		VOTLink link;

		for (int i = 0; i < numOfElts; i++)
		{
			f.getLink(link, i);
			printLinkContents(link, i+1);
		}
	}

	//Print details of Field/Param values, if available
	f.getNumOfValues(numOfElts);
	cout << "\nNumber of VALUES is " << numOfElts << endl;
	if (numOfElts > 0)
	{
		VOTValues values;

		for(int i=0; i<numOfElts; i++)
		{
			f.getValues(values, i);
			cout << "VALUES " << (i+1) << " : " << endl;
			printValuesContents(values);
		}
	}

}

/*
* Print Field data
*/
void printFieldContents(VOTField &f, int index)
{
	char * str = NULL;
	cout << "\n";

	//Print the Field type, if available
	field_type tp;
	if (VOT_SUCCESS == f.getType(tp))
	{
		cout << "Field " << index << " type is " << tp << " , ";
	}

	//Print the Field description, if available
	if(VOT_SUCCESS == f.getDescription(str) && NULL != str)
	{
		cout << "Field "<< index << " description is " << str << " , ";
		delete[] str;
	}

	printFieldParamContents(f, index, true);

}

/*
* Print Values data
*/
void printValuesContents(VOTValues &v)
{
	char * str = NULL;
	cout << "\n";

	//Print Values ID, if available
	if (VOT_SUCCESS == v.getID(str) && NULL != str)
	{
		cout << "ID is " << str << " , ";
		delete[] str;
	}

	//Print Values Type, if available
	values_type tp;
	if (VOT_SUCCESS == v.getType(tp))
	{
		cout << "Type is " << tp << " , ";
	}

	//Print Values NULL, if available
	if (VOT_SUCCESS == v.getNull(str) && NULL != str)
	{
		cout << "NULL is " << str << " , ";
		delete[] str;
	}

	//Print Values Valid, if available
	bool b;
	if (VOT_SUCCESS == v.isValid(b))
	{
		cout << "Valid is " << b << " , ";
	}

	int numOfElts = 0;

	//Print details of Values min, if available
	VOTRange * range;
	if(VOT_SUCCESS == v.getMaximum(range) && NULL != range)
	{
		cout << endl << "MAX : ";
		printRangeContents(*range);
		delete range;
	}

	//Print details of Values max, if available
	if(VOT_SUCCESS == v.getMinimum(range) && NULL != range)
	{
		cout << endl << "MIN : ";
		printRangeContents(*range);
		delete range;
	}

	//Print details of Values options, if available
	v.getNumOfOptions(numOfElts);
	cout << "\nNumber of OPTIONS " << numOfElts << endl;
	if(numOfElts > 0)
	{
		VOTOption option;

		for(int i=0; i<	numOfElts; i++)
		{
			v.getOption(option, i);
			printOptionContents(option);
		}
	}
}

/*
* Print Renge data
*/
void printRangeContents(VOTRange &r)
{
	char * str = NULL;
	cout << "\n";

	//Print Range Id, if available
	if (VOT_SUCCESS == r.getValue(str) && NULL != str)
	{
		cout << "Value is " << str << " , ";
		delete[] str;
	}

	//Print Range Inclusive, if available
	bool b;
	if (VOT_SUCCESS == r.isInclusive(b))
	{
		cout << "Inclusive is " << b << " , ";		
	}

	//Print Range PCData, if available
	if (VOT_SUCCESS == r.getPCData(str) && NULL != str)
	{
		cout << "PCData is " << str << " , ";
		delete[] str;
	}
}

/*
* Print Options data
*/
void printOptionContents(VOTOption &o)
{
	char *str = NULL;
	cout << "\n";

	//Print Option ID, if available
	if (VOT_SUCCESS == o.getName(str) && NULL != str)
	{
		cout << "Name is " << str << " , ";
		delete[] str;
	}

	//Print Option Value, if available
	if (VOT_SUCCESS == o.getValue(str) && NULL != str)
	{
		cout << "Value is " << str << " , ";
		delete[] str;
	}

	int numOfElts = 0;

	//Print details of nested Options, if available
	o.getNumOfOptions(numOfElts);
	cout << "\nNumber of OPTIONS " << numOfElts << endl;
	if(numOfElts > 0)
	{
		VOTOption option;

		for(int i=0; i<	numOfElts; i++)
		{
			o.getOption(option, i);
			printOptionContents(option);
		}
	}
}

/*
* Print Row data
*/
void printRowContents(VOTRow &r, VOTTable &table)
{
	char * str = NULL;	
	int numOfElts;

	//Print details of the Columns in the Row
	r.getNumOfColumns(numOfElts);	
	if (numOfElts > 0)
	{
		VOTColumn col;
		VOTField fld;
		field_datatype dt;

		for (int i = 0; i < numOfElts; i++)
		{		
			if (VOT_SUCCESS == table.getField(fld, i))
			{
				fld.getDatatype(dt);
				r.getColumn(col, i);		
				printData(col, dt);
			}
		}

	}
}

/*
* Print Column data
*/
void printData(VOTColumn &c, field_datatype dt)
{
	int numOfElements = 0;
		
	//Check the datatype of the data
	switch (dt) 
	{
		//Integer array
		case IntType :
			{
				int *intArray;
				int *valid;
				if (c.getIntArray(intArray, valid, numOfElements) == VOT_SUCCESS)
				{
					cout << endl << "Number of elements is " << numOfElements << endl;
					cout << "Data is " ;
					for (int i = 0; i < numOfElements; i ++)
					{
					if(valid[i] == VOT_SUCCESS)
						 cout << intArray[i] << " ";
					else
					 cout << "Invalid Datatype";
					}
					
					delete[] intArray;
					delete[] valid;
				}
				break;
			}

		//Unicode array
		case UnicodeCharType :
			{
				unsigned short *unicodeArray;
				if (c.getUnicodeArray (unicodeArray, numOfElements) == VOT_SUCCESS)
				{
					
					cout << endl << "Number of elements is " << numOfElements << endl;
					cout << "Unicode data in decimal is " ;
					for (int i = 0; i < numOfElements; i ++)
					{
						 cout << unicodeArray[i] << " ";
						 
					}

					cout << endl << endl;					
					delete[] unicodeArray;
				}
			}

			//UnsignedByte array
			case UnsignedByteType :
			{
				unsigned char *charArray;
				if (c.getByteArray(charArray, numOfElements ) == VOT_SUCCESS)
				{
					cout << endl << "Number of elements is " << numOfElements << endl;
					cout << "Data is " ;
					for (int i = 0; i < numOfElements; i ++)
					{
						 cout << charArray[i] << " ";
					}
					
					delete[] charArray;
				}
				break;
			}

			//Bit array
			case BitType :
			{
				char *cArray;
				if (c.getBitArray(cArray, numOfElements ) == VOT_SUCCESS)
				{
					cout << endl << "Number of elements is " << numOfElements << endl;
					cout << "Data is " ;
					for (int i = 0; i < numOfElements; i ++)
					{
						printBits(cArray[i]);
						// cout << cArray[i] << " ";
					}
					
					delete[] cArray;
				}
				break;
			}

			//Long array
			case LongType :
			{
				long *longArray;
				int *valid;
				if (c.getLongArray(longArray, valid, numOfElements ) == VOT_SUCCESS)
				{
					cout << endl << "Number of elements is " << numOfElements << endl;
					cout << "Data is " ;
					for (int i = 0; i < numOfElements; i ++)
					{
					if(valid[i] == VOT_SUCCESS)
						 cout << longArray[i] << " ";
					else
					 cout << "Invalid Datatype";
					}
					
					delete[] longArray;
					delete[] valid;
				}
				break;
			}

			//Short array
			case ShortType :
			{
				short *shortArray;
				int *valid;
				if (c.getShortArray(shortArray, valid, numOfElements ) == VOT_SUCCESS)
				{
					cout << endl << "Number of elements is " << numOfElements << endl;
					cout << "Data is " ;
					for (int i = 0; i < numOfElements; i ++)
					{
						if(valid[i] == VOT_SUCCESS)
						 cout << shortArray[i] << " ";
						else
						 cout << "Invalid Datatype";
					}
					delete[] shortArray;
					delete[] valid;
				}
				break;
			}

			//Float array
			case FloatType :
			{
				float *floatArray;
				int *valid;
				if (c.getFloatArray(floatArray, valid, numOfElements ) == VOT_SUCCESS)
				{
					cout << endl << "Number of elements is " << numOfElements << endl;
					cout << "Data is " ;
					for (int i = 0; i < numOfElements; i ++)
					{
					if(valid[i] == VOT_SUCCESS)
						 cout << floatArray[i] << " ";
					else
					 cout << "Invalid Datatype";
					}
					delete[] floatArray;
					delete[] valid;
				}
				break;
			}

			//Float complex array
			case FloatComplexType :
			{
				float *floatArray;
				int *valid;
				if (c.getFloatComplexArray(floatArray, valid, numOfElements ) == VOT_SUCCESS)
				{
					cout << endl << "Number of elements is " << numOfElements << endl;
					cout << "Data is " ;
					for (int i = 0; i < numOfElements; i ++)
					{
					if(valid[i] == VOT_SUCCESS)
						 cout << floatArray[i] << " ";
					else
					 cout << "Invalid Datatype";
					}
					delete[] floatArray;
					delete[] valid;
				}
				break;
			}

			//Double array
			case DoubleType :
			{
				double *doubleArray;
				int *valid;
				if (c.getDoubleArray(doubleArray, valid, numOfElements ) == VOT_SUCCESS)
				{
					cout << endl << "Number of elements is " << numOfElements << endl;
					cout << "Data is " ;
					for (int i = 0; i < numOfElements; i ++)
					{
					if(valid[i] == VOT_SUCCESS)
						 cout << doubleArray[i] << " ";
					else
					 cout << "Invalid Datatype";
					}
					delete[] doubleArray;
					delete[] valid;
				}
				break;
			}

			//Double complex array
			case DoubleComplexType :
			{
				double *doubleArray;
				int *valid;
				if (c.getDoubleComplexArray(doubleArray, valid, numOfElements ) == VOT_SUCCESS)
				{
					cout << endl << "Number of elements is " << numOfElements << endl;
					cout << "Data is " ;
					for (int i = 0; i < numOfElements; i ++)
					{
					if(valid[i] == VOT_SUCCESS)
						 cout << doubleArray[i] << " ";
					else
					 cout << "Invalid Datatype";

					}
					delete[] doubleArray;
					delete[] valid;
				}
				break;
			}

			//Boolean array
			case BooleanType :
			{
				Bool *boolArray;
				int *valid;
				if (c.getLogicalArray(boolArray, valid, numOfElements ) == VOT_SUCCESS)
				{
					cout << endl << "Number of elements is " << numOfElements << endl;
					cout << "Data is " ;
					for (int i = 0; i < numOfElements; i ++)
					{
					if(valid[i] == VOT_SUCCESS)
						 cout << boolArray[i] << " ";
					else
						cout << "Invalid Datatype";
					}
					delete[] boolArray;
					delete[] valid;
				}
				break;
			}

			//Char array
			case CharType :
			{
				char *charArray;
				if (c.getCharArray(charArray, numOfElements ) == VOT_SUCCESS)
				{
					cout << endl << "Number of elements is " << numOfElements << endl;
					cout << "Data is =>" ;
					for (int i = 0; i < numOfElements; i ++)
					{
						 cout << charArray[i] << " ";
					}
					cout << "<=" << endl;
					delete[] charArray;
				}
				break;
			}

			//Unknown datatype
			default :
			{ 
				cout << "Unknown Datatype ! " << dt << endl; 
				break; 
			}

		} // switch

}

/*
* Print the data bit-by-bit
*/
void printBits(char c)
{
	const unsigned char mask = (char) 0x80;
	unsigned int firstbit = 0;

	for (int i =0; i < 8; i++)
	{
		firstbit = c & mask;
		if (firstbit == 0)
		{
			cout << "0 ";
		} 
		else 
		{
			cout << "1 ";
		}
	
		c = c << 1;
	}
	cout << "  ";
}

/*
void printColumnContents(VOTColumn &c)
{
	//cout << "Column #?" << " , ";
	char * str = NULL;
	int size = 0;
	unsigned short * array;

	if(VOT_SUCCESS == c.getUnicodeArray(array, size) && NULL != array)
	{
		for (int i = 0; i < size; i++)
		{
			cout << " [" << (i+1) <<"] = " << array[i] << " , ";
		}
	}
	
	if(VOT_SUCCESS == c.getCharArray(str, size) && NULL != str)
	{
		cout << "Value is " << str << " , ";
		delete[] str;
	}
}*/

/*
* Print Param data
*/
void printParamContents(VOTParam &p, int index)
{
	char * str = NULL;
	cout << "\n";

	//Print param ID, if available
	if (VOT_SUCCESS == p.getValue(str) && NULL != str)
	{
		cout << "Param " << index << " value is " << str << " , ";
		delete[] str;
	}

	//Print param description, if available
	if(VOT_SUCCESS == p.getDescription(str) && NULL != str)
	{
		cout << "Param " << index << " description is " << str << " , ";
		delete[] str;
	}

	printFieldParamContents(p, index, false);
}


/*
* Print Definition data.
*/
void printDefinitionContents(VOTDefinition &d)
{
	char * str = NULL;

	//Print details of the Definition coosys, if available
	VOTCoosys * coosys = NULL;
	if (VOT_SUCCESS == d.getCoosys(coosys) && NULL != coosys)
	{
		printCoosysContents(*coosys);
		delete coosys;
	}

	//Print details of the Definition param, if available
	VOTParam * param = NULL;
	if (VOT_SUCCESS == d.getParam(param) && NULL != param)
	{
		printParamContents(*param, 1);
		delete param;
	}
}
